@@ -1,5 +1,5 @@
 from .exec import (
-    init_engin,
+    init_db,
     connection,
     transaction,
     with_connection,
@@ -8,12 +8,13 @@ from .exec import (
     insert,
     save,
     save_sql,
+    batch_insert,
     batch_execute,
     get,
     select,
     select_one,
     query,
-    query_one
+    query_one,
+    get_connection
 )
-
-from .constant import Engin
+from .support import DBError
