@@ -1,12 +1,12 @@
 import re
-from .engin import Engin
+from .engine import Engine
 from typing import Sequence
 from functools import lru_cache
 from .constant import CACHE_SIZE, NAMED_REGEX
 
 def insert_sql_args(table: str, **kwargs):
     cols, args = zip(*kwargs.items())
-    sql = Engin.create_insert_sql_intf(table, cols)
+    sql = Engine.create_insert_sql_intf(table, cols)
     return sql, args
 
 
@@ -18,7 +18,7 @@ def batch_insert_sql_args(table: str, *args):
     args = get_batch_args(*args)
     args = [zip(*arg.items()) for arg in args]  # [(cols, args)]
     cols, args = zip(*args)  # (cols), (args)
-    sql = Engin.create_insert_sql_intf(table, cols[0])
+    sql = Engine.create_insert_sql_intf(table, cols[0])
     return sql, args
 
 
